แพ็คเกจนี้เป็นแพ็คเกจ python ที่โชว์ข้อมูลเกี่ยวกับ Wise System
===============================================================

PyPi: https://pypi.org/project/mynameisWS/

สวัสดีจ้าาาา นี่คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับ WS ท่านสามารถดูลิ้งค์
FB หรือ Youtube ได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install mynameisWS

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from mynameisWS import WS

   ws = WS() # ประกาศชื่อคลาส
   ws.show_name() # โชว์ชื่อ
   ws.show_youtube() # โชว์ลิ้งค์ Youtube
   ws.about() # เกี่ยวกับ WS
   ws.show_art() # โชว์ Ascii Art

พัฒนาโดย: Wise System FB: https://www.facebook.com/

YouTube: https://www.youtube.com/
